@@ -10,26 +10,42 @@ from PIL import Image, ExifTags, ImageDraw, ImageFont
 def read_img(img):
     """
     从输入参数读取图像，转换成二进制字节流格式
-    :param img: 存在4种可能形式：图像文件路径名 | 图像文件二进制字节流 | 图像文件二进制字节流的base64编码字符串 | 图像文件二进制字节流的base64编码URL字符串
-    :return: 二进制字节流
+    :param img:
+        存在5种可能形式：
+            - np.ndarray格式的图像数据（默认为RGB格式）
+            - 图像文件路径名
+            - 图像文件二进制字节流
+            - 图像文件二进制字节流的base64编码字符串
+            - 图像文件二进制字节流的base64编码URL字符串
+    :return: (PIL.Image格式的图像对象, np.ndarray格式的图像数据(RGB格式))
     """
     try:
+        if isinstance(img, np.ndarray):
+            return np2pil(img), img
+
         if isinstance(img, bytes):
-            return img
+            img_pil = bin2pil(img)
+            img = np.asarray(img_pil)
+            return img_pil, img
 
         if not isinstance(img, str):
-            return None
+            return None, None
 
         if img.endswith('.jpg') or img.endswith('.jpeg') or img.endswith('.png') or img.endswith('.gif') or img.endswith('.bmp'):
             with open(img, 'rb') as file:
-                return file.read()
+                img = file.read()
+                img_pil = bin2pil(img)
+                img = np.asarray(img_pil)
+                return img_pil, img
 
         if img.startswith('data:image/'):
             img = re.sub('^data:image/.+;base64,', '', img)
         img = base64.b64decode(img.encode())
-        return img
+        img_pil = bin2pil(img)
+        img = np.asarray(img_pil)
+        return img_pil, img
     except:
-        return None
+        return None, None
 
 
 def bin2pil(img):
@@ -98,6 +114,7 @@ def resize_pil(img, new_size=1024):
     return img
 
 
+# box中坐标格式为： x1, y1, w, h
 def draw_all_box_and_label_pil(img, boxes, outline='red', width=2, text_color='white', text_bg_color='red', text_size=24, font_path='app/fonts/wqy-zenhei.ttc'):
     draw = ImageDraw.Draw(img)
     for (label, box) in boxes:
@@ -120,6 +137,7 @@ def draw_all_box_and_label_pil(img, boxes, outline='red', width=2, text_color='w
     return img
 
 
+# box中坐标格式为： x1, y1, x2, y2
 def draw_all_box_and_label_pil2(img, boxes, outline='red', width=2, text_color='white', text_bg_color='red', text_size=24, font_path='app/fonts/wqy-zenhei.ttc'):
     draw = ImageDraw.Draw(img)
     for (label, box) in boxes:
@@ -142,6 +160,7 @@ def draw_all_box_and_label_pil2(img, boxes, outline='red', width=2, text_color='
     return img
 
 
+# box中坐标格式为： x1, y1, w, h
 def draw_all_box(img, boxes, outline='red', width=2):
     draw = ImageDraw.Draw(img)
     for box in boxes:
@@ -151,6 +170,7 @@ def draw_all_box(img, boxes, outline='red', width=2):
     return img
 
 
+# box中坐标格式为： x1, y1, x2, y2
 def draw_all_box2(img, boxes, outline='red', width=2):
     draw = ImageDraw.Draw(img)
     for box in boxes:
